#!/bin/bash
#
# usage: ./restore.sh
#
#
# This directory contains the files used to build the BUP restore flash object files. 
#
# Build_restore.sh script commands may be run individually at a unix, linux, or Nios II EDS command shell.
#
#
# html_a2gx hardware sof files from the project directories are converted
# using Nios II Tool sof2flash to attain flash files:
#
# sof2flash --offset=0x020000 --input=a2gx125_fpga_bup.sof --output=a2gx125_fpga_bup.flash
# sof2flash --offset=0x640000 --input=bts_config.sof    --output=bts_config.flash
#
# html_a2gx software - run make flash from the app\web_server dir 
# after running make to build software elf
#
# make flash
#
#
# actual rebuilding script of restore files can happen here for the end user:
#
# For eventual memory map - cat flash files for each ext_flash die (device is dual die with distinct CFI tables
#
#
#

echo "
Building restore flash file for flash...
cat boot_code.flash pfl_bits.flash boardInfo.srec a2gx125_fpga_bup.flash bts_config.flash html_a2gx125.flash ext_flash.flash > temp_restore.flash"

cat boot_code.flash pfl_bits.flash boardInfo.srec a2gx125_fpga_bup.flash bts_config.flash html_a2gx125.flash ext_flash.flash > temp_restore.flash

# delete unnecessary s-records after concatenation

echo "
Deleting unnecessary s-records within the flash files post-concatenation...
sed '/^S[05789]/ d' temp_restore.flash > restore_a2gx125_fpga.flash "

sed '/^S[05789]/ d' temp_restore.flash > restore_a2gx125_fpga.flash 

# delete temp files 

echo "
Deleting temp files...
rm -f temp_restore.flash"

rm -f temp_restore.flash

echo "
Done building restore flash file!
"

#
# To restore flash after building the restore files, follow instructions as specified in  
# the User's Guide, chapter entitled: "Restoring the Flash Device with the Factory Settings"
#
#
# Note that the flash files may also be programmed individually using nios2-flash-programmer as follows:
#
# nios2-flash-programmer -b 0x08000000 html_a2gx125.flash
# nios2-flash-programmer -b 0x08000000 a2gx125_fpga_bup.flash
# nios2-flash-programmer -b 0x08000000 bts_config.flash
# nios2-flash-programmer -b 0x08000000 ext_flash.flash
# nios2-flash-programmer -b 0x08000000 pfl_bits.flash
# nios2-flash-programmer -b 0x08000000 boot_code.flash
#
# For proper restore to work, the board FPGA should still also be one-time configured as described in 
# the User's Guide, entitled: "Restoring the Flash Device with the Factory Settings"
#